# \donttest{
data(testyxm) # testyxm is a list called dt
dataWithMiss <- testyxm$dataMissing
fit <- emBinRegMixedMAR(Wheeze ~ city + soc + cond,
data = dataWithMiss, adtnlCovforR = c("age"),
biascorrectn=TRUE)
#display summary of the beta estimates of the model
fit$beta
#display summary of the alpha estimates of the model used
#for non-ignorability setting of the missing responses
fit$alpha
# Examples using Firth (1993) type bias reduction. Complete case analysis or
# biascorrection=FALSE encounters separation
fit <- emBinRegMixedMAR(resp~Numnill+Numsleep+Smoke+Set+Reftime,
data=meningitis60ymis, biascorrectn=TRUE)
#display summary of the beta estimates of the model
fit$beta
#display summary of the alpha estimates of the model used
#for non-ignorability setting of the missing responses
fit$alpha
# }
Run the code above in your browser using DataLab