powered by
testyxm
A test list data that returns a list called testyxm with two components:
dataOriginal: The original data set without missing values.
dataOriginal
dataMissing: The data set with artificially introduced missing values.
dataMissing
data(testyxm)
A list with the following components:
A data frame with several rows and columns representing various variables.
A data frame with missing values corresponding to the same structure as dataOriginal.
Simulated Test Data
This dataset is a list called testyxm that contains two data frames: dataOriginal and dataMissing.
Pradhan, V., Nychka, D., and Bandyopadhyay, S. (2024). Beyond the Odds: Fitting Logistic Regression with Missing Data in Small Samples (submitted).
data(testyxm) Fulldata <- testyxm$dataOriginal Missdata <- testyxm$dataMissing
Run the code above in your browser using DataLab