simulateMissDfYorX: Simulate missing covariate or missing responses data based on an input covariate data
Description
This function generates missing covariate or missing responses data. The missing data generation in the last two supplied covariates will be generated based on a predefined mechanisms. Missing data generation in the response variable will be based on the suppilied true alpha.