theta_back_2_data: This function performs data augmentation on the provided dataset.
Description
This function performs data augmentation on the provided dataset.
Usage
theta_back_2_data(theta, data, MissingVars)
Value
A data frame containing the augmented data.
Arguments
- theta
A data frame containing the theta.
- data
A data where theta to be merged.
- MissingVars
A variable with missing data